

/*
 * Telemetry and Custom Command Sample Arduino Code
 *   Telemetry Example: Monitor an extended I/O register IRue and send to control panel display
 *   Command Example:   Add Robot unique MOVE, BLINK, and SERVO commands
 */
 
//#include "C:\Program Files (x86)\Arduino 1_6_5\hardware\arduino\avr\libraries"
#include <Robot3DoTBoard.h>     // instantiated as Robot3DoT at end of class header
#include <EEPROM.h>
//#include <Wire.h>               // I2C support
//#include <Servo.h>
#include <SoftwareServoModified.h>
//#include <FuckThis.h>

void moveHandler (uint8_t cmd, uint8_t param[], uint8_t n);
void MotorHandler (uint8_t cmd, uint8_t param[], uint8_t n);
void servoHandler (uint8_t cmd, uint8_t param[], uint8_t n);
Robot3DoTBoard Robot3DoT;       // instantiated as Robot3DoT at end of class header

SoftwareServo servo_pin_13;
int pos = 0;
int QRD1114_PIN = A3; // Sensor output voltage
int QRD1114_PIN2 = A4; // second sensor
int RE;  // Corresponds to motor A
int RE2; // Corresponds to motor B
//int z = 0;
//int sig = 2; // motorA
//int sig2 = 3; // motorB
//int IR;
//int IR2;

 /*
  * Command Example
  * Step 1: Assign new command mnemonics ID numbers  
  *         In our example we will be adding 3 custom commands (2 new and one predefined). 
  *         The predefined MOVE command is intercepted and our robot unique code is to be 
  *         run instead. The MOVE command mnemonic ID 0x01 is already defined in Configure.h 
  *         The next two commands are new and assigned to the first two addresses in the 
  *         custom command address space 0x40 - 0x5F. 
  */
#define MOTOR       0x40
#define SERVO       0x41


Motor motorA; // you can name your motors whatever you want
Motor motorB;// in this case I used motorA and motorB
const uint8_t CMD_LIST_SIZE = 3;   // we are adding 3 commands (MOVE, BLINK, SERVO) 

 /*
  * Command Example
  * Step 2: Register commands by linking IDs to their corresponding command handlers   
  *         In our example when the MOVE command is intercepted the moveHandler is to be run.   
  *         In a similar fashion the BLINK command calls the blinkHandler and SERVO the     
  *         servoHandler.
  */
void moveHandler (uint8_t cmd, uint8_t param[], uint8_t n);
void MotorHandler (uint8_t cmd, uint8_t param[], uint8_t n);
void servoHandler (uint8_t cmd, uint8_t param[], uint8_t n);

Robot3DoTBoard::cmdFunc_t onCommand[CMD_LIST_SIZE] = {{MOVE,moveHandler}, {MOTOR,MotorHandler}, {SERVO,servoHandler}}; 

 /*
  * Telemetry Example
  * Step 1: Instantiate packet 
  *         In our example we simulate a current sensor wired to MOTOR 2. MOTOR2_CURRENT_ID 
  *         is defined as 0x02 in Configure.h 
  *         To simulate the data stream coming from the sensor we will read ATmega32U4 
  *         Register OCR4D which controls the duty cycle of MOTOR 2.   
  */
Packet motorPWM(MOTOR2_CURRENT_ID);  // initialize the packet properties to default IRues

void setup()
{
  Serial.begin(9600);               // default = 115200  
  Robot3DoT.begin();
//  pinMode(sig,INPUT);
//  pinMode(sig2,INPUT);
  pinMode(QRD1114_PIN, INPUT);
  pinMode(QRD1114_PIN2, INPUT);
 /*
  * Command Example
  * Step 3: Tell 3DoT Robot software about new commands
  */

Robot3DoT.setOnCommand(onCommand, CMD_LIST_SIZE);    

 /* Telemetry Example
  * Step 2: Modify default IRues assigned to internal properties as needed.   
  *         Before a packet is created and sent, it is qualified. Specifically,
  *         the data in a packet must change by some amount from the previous  
  *         packet and may not be sent with at a period less than some IRue. 
  *         In most cases you can leave these IRues at their default IRues.
  */
  motorPWM.setAccuracy(1);          // change sensor accuracy from +/-2 DN to +/-1 DN    (-- this line is optional --)
  motorPWM.setSamplePeriod(500);    // change sample period from 1 second to 0.5 seconds (-- this line is optional --)
  motorA.begin(5,10,9); //begin(control_pin1,control_pin2,pwmPin) --> set up  motor control pins
  motorB.begin(19,20,6); 
  servo_pin_13.attach(13);
  pos = 90;
  servo_pin_13.write(pos);
  SoftwareServo::refresh();
}

void loop()
{
  
  Robot3DoT.loop();
   ReadRE();
  //void walkforward();
 /*
  * Telemetry Example
  * Step 3: Read sensor and send packet 
  *         To simulate the data stream coming from the sensor we will read ATmega32U4 
  *         Register OCR4D which controls the duty cycle of MOTOR 2. This code segment
  *         uses the preproccessor conditional directives #if to make sure that an MCU
  *         with a ATmega32U4 or ATmega16U4 is selected under Tools > Board. 
  */
  #if defined(__AVR_ATmega32U4__) || defined(__AVR_ATmega16U4__)
    uint16_t pwm_reading = (uint16_t) OCR4D;  // read 8-bit Output Compare Register Timer 4D and cast to 16-bit signed word
    motorPWM.sendSensor(pwm_reading);
  #else
    // Timer/Counter 0 registers set by UNO Bootloader (freq. = 1 Khz) 
    // Timer/Counter Control Registers TCCR0B = 0x03 (Prescaler of 64) and TCCR0A (Fast PWM, TOP = 0xFF) = 0x03
    uint16_t pwm_reading = (uint16_t) OCR0B;  
    motorPWM.sendSensor(pwm_reading); 
  #endif 
}

/*
 * Command Example
 * Step 4: Write command handlers 
 */

/*
 * User Defined Command BLINK (0x40) Example        
 * A5 01 40 E4
 */
void MotorHandler (uint8_t cmd, uint8_t param[], uint8_t n)
{ 

}  // blinkHandler

/*
 * Override MOVE (0x01) Command Example       
 * A5 05 01 01 80 01 80 A1
 */
void moveHandler (uint8_t cmd, uint8_t param[], uint8_t n)
{
    ReadRE();
  for (pos = pos; pos<=120; pos++)
    {
      servo_pin_13.write(pos);
      delay(15);
      SoftwareServo::refresh();
    }

     ReadRE();   //The left leg is forward and the right leg is behind and the Cog is over the left leg.
    motorA.go(param[0],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
    //in my case I used 1 to move forward and a 255 for max speed
    motorB.go(param[2],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
//    delay(500); // need to calculate delay
     ReadRE();
//      IR = digitalRead(sig);
//      //Serial.println(IR);
//      IR2 = digitalRead(sig2);
  
    while ((RE<550)&&((RE2<=1100)&&(RE2>5))) 
    {
    motorA.go(param[0],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
    //in my case I used 1 to move forward and a 255 for max speed
//    IR = digitalRead(sig);
     ReadRE();
    motorB.go(param[2],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
//    IR2 = digitalRead(sig2);
     ReadRE();
    }
    
    if ((RE>=550)&&((RE2<=1100)&&(RE2>5)))
    {
      motorA.brake();
       ReadRE();
      while ((RE2<=1100)&&(RE2>5))
      {
         motorB.go(param[2],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
//         IR2 = digitalRead(sig2);
       ReadRE();
      }
      if ((RE2==1100)||(RE2<=5))
      {
        motorB.brake();
         ReadRE();
      }
    }
    
    if ((RE<550)&&((RE2==1100)||(RE2<=5)))
    {
      motorB.brake();
       ReadRE();
      while (RE<550)
      {
         motorA.go(param[0],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
//         IR = digitalRead(sig);
         ReadRE();
      }
      if (RE>=550)
      {
        motorA.brake();
         ReadRE();
      }
    }

    //IR = digitalRead(sig);
    //IR2 = digitalRead(sig2);
       ReadRE();
      
    
    
  for (pos=pos; pos>=60; pos--)
    {
      servo_pin_13.write(pos);
      delay(15);
      SoftwareServo::refresh();
    }
    

    motorA.go(param[0],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
    //in my case I used 1 to move forward and a 255 for max speed
    motorB.go(param[2],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
    delay(500); // need to calculate delay

//      IR = digitalRead(sig);
      //Serial.println(IR);
//      IR2 = digitalRead(sig2);
     ReadRE();
  
    while (((RE<1100)&&(RE>5))&&(RE2<550)) //COG is over the right leg.
    {
    motorA.go(param[0],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
    //in my case I used 1 to move forward and a 255 for max speed
//    IR = digitalRead(sig);
     ReadRE();
    motorB.go(param[2],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
//    IR2 = digitalRead(sig2);
     ReadRE();
    }
     ReadRE();
    if (((RE==1100)||(RE<5))&&(RE2<550))
    {
      motorA.brake();
       ReadRE();
      while (RE2<550)
      {
         motorB.go(param[2],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
//         IR2 = digitalRead(sig2);
     ReadRE();
      }
      if (RE2>=550)
      {
        motorB.brake();
         ReadRE();
      }
    }
    
    if (((RE<1100)&&(RE>5))&&(RE2>=550))
    {
      motorB.brake();
       ReadRE();
      while (((RE<1100)&&(RE>5)))
      {
         motorA.go(param[0],0x40);// go(direction,pwm) --> direction: FORWARD =1, BACKWARD =2, BRAKE = 3, RELEASE = 4; pwm range(0-255) used to control the speed of the motor
//         IR = digitalRead(sig);
     ReadRE();
      }
      if ((RE==1100)||(RE<=5))
      {
        motorA.brake();
         ReadRE();
      }
    }
    
      
}  // moveHandler

/*
 * User Defined Command SERVO (0x41) Example       
 * Rotate servo to 90 degrees
 * A5 02 41 90 76
 */
void servoHandler (uint8_t cmd, uint8_t param[], uint8_t n)
{
  Serial.write(cmd);             // servo command = 0x41
  Serial.write(n);               // number of param = 1
  for (int i=0;i<n;i++)          // param = 90 degrees
  {
    Serial.write (param[i]);
  }  
}  // servoHandler


void ReadRE()
{
  // Read in the ADC and convert it to a voltage:
  int RE = analogRead(QRD1114_PIN);
  int RE2 = analogRead(QRD1114_PIN2);
//  if (proximityADC < 630){
//    IR = HIGH;
//  }
//  else {
//    IR = LOW;
//  }
//  if (proximityADC2 < 630){
//  IR2 = HIGH;
//  }
//  else {
//    IR2 = LOW;
//  }
Serial.println(RE);
Serial.println(RE2);
delay(10);
}

